--
-- ATTENTION: This is a free software. 
--            View the LICENSE.txt file for license information
--

------------------------------------------------------------------------------
-- FUNCTION: public.drop_snapshot
--
-- Removes a SNAPSHOT previously created with create_snapshot
------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION public.drop_snapshot(schemaname text, snapshotname text)
  RETURNS bool AS
$BODY$
use strict;
use DBI;
use constant TRUE => 1;
use constant FALSE => "";
#-- Function parameters
my ($schemaname, $snapshotname) = @_;
$schemaname = lc($schemaname);
$snapshotname = lc($snapshotname);
#-- Set this to 1 for debugging messages
$main::DEBUG=0;
#-- Localhost superuser connection
my $dbh_local = DBI->connect('dbi:Pg:dbname=gabcmt', 'postgres', undef, {AutoCommit => 0});
my $dbh_remote;
my $sql;
my $rs;
my $row;
my $masterschema;
my $mastername;
my $snapshot;
my $dblink;
my $attr_href;

if (! snapshotExists($dbh_local, $schemaname, $snapshotname)) {
	elog ERROR, "Snapshot '$schemaname.$snapshotname' does not exist";
}

my $snapshot = getSnapshot($dbh_local, $schemaname, $snapshotname);
if ("$snapshot->{'dblinkid'}" eq '') {
	#-- refresh local
	$dbh_remote = $dbh_local;
} else {
	$dblink = getDblinkById($dbh_local, $snapshot->{'dblinkid'});
	if ($dblink) {
		#--create the remote database connection
		$attr_href = eval($dblink->{'attributes'});
		$dbh_remote = dbiGetConnection(
			$dblink->{'datasource'}
			, $dblink->{'username'}
			, $dblink->{'password'}
			, $attr_href
			);
	} else {
		$dbh_remote = $dbh_local;
	}
}

($masterschema, $mastername) = retrieveMasterForSnapshot($dbh_remote, $snapshot);
if (snapshotLogExists($dbh_remote, $masterschema, $mastername)) {
	call_driver_function($dbh_remote, 'snapshot_do', 'UNREGISTER', $masterschema, $mastername, $snapshot->{'snapid'});
}
$dbh_remote->commit;
$dbh_remote->disconnect;

#-- Actually drop the SNAPSHOT placeholder
$sql = <<SQL;
DROP TABLE $schemaname.$snapshotname
SQL
$rs = spi_exec_query($sql);
if ($rs->{status} eq 'SPI_OK_UTILITY') {
	elog NOTICE, "Snapshot dropped" if $main::DEBUG==1;
} else {
	elog ERROR, "Could not drop Snapshot '$schemaname.$snapshotname'. $rs->{status}";
}

#-- Then delete the SNAPSHOT entry in %BASE_SCHEMA%.pg_snapshots
$sql = <<SQL;
DELETE FROM %BASE_SCHEMA%.pg_snapshots 
WHERE schemaname=?
	AND snapshotname=?
SQL
$rs = $dbh_local->prepare($sql);
$rs->execute(($schemaname, $snapshotname));
if (! $rs->err) {
	elog NOTICE, "Snapshot entry removed" if $main::DEBUG==1;
} else {
	elog ERROR, "Could not remove Snapshot entry '$schemaname.$snapshotname'. $rs->{status}";
}
$dbh_local->commit;
$dbh_local->disconnect;
#-- All done. Let's return TRUE
return TRUE;

INCLUDE 'sqlLookup.pl'
INCLUDE 'snapshotExists.pl'
INCLUDE 'getSnapshot.pl'
INCLUDE 'getDblinkById.pl'
INCLUDE 'dbiGetConnection.pl'
INCLUDE 'retrieveMasterForSnapshot.pl'
INCLUDE 'snapshotLogExists.pl'
INCLUDE 'call_driver_function.pl'


$BODY$
  LANGUAGE 'plperlu' VOLATILE;
ALTER FUNCTION public.drop_snapshot(schemaname text, snapshotname text) OWNER TO postgres;
COMMENT ON FUNCTION public.drop_snapshot(schemaname text, snapshotname text) IS $$
This function is part of PostgreSQL::Snapshots project.
This is the function that removes a snapshot.
$$;
